summaryrefslogtreecommitdiffstats
path: root/scripts/make_gitrev.sh
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/make_gitrev.sh')
-rwxr-xr-xscripts/make_gitrev.sh30
1 files changed, 29 insertions, 1 deletions
diff --git a/scripts/make_gitrev.sh b/scripts/make_gitrev.sh
index 8db4de931..f5c743b13 100755
--- a/scripts/make_gitrev.sh
+++ b/scripts/make_gitrev.sh
@@ -27,10 +27,21 @@
set -e -u
+dist=no
+distdir=.
+while getopts D: flag
+do
+ case $flag in
+ \?) echo "Usage: $0 [-D distdir] [file]" >&2; exit 1;;
+ D) dist=yes; distdir=${OPTARG};;
+ esac
+done
+shift $((OPTIND - 1))
+
top_srcdir="$(dirname "$0")/.."
GITREV="${1:-include/zfs_gitrev.h}"
# GITREV should be a relative path (relative to top_builddir)
case "${GITREV}" in
/*) echo "Error: ${GITREV} should be a relative path" >&2
exit 1;;
@@ -38,10 +49,27 @@ esac
ZFS_GITREV=$({ cd "${top_srcdir}" &&
git describe --always --long --dirty 2>/dev/null; } || :)
+
+if [ "x${ZFS_GITREV}" = x ]
+then
+ # If the source directory is not a git repository, check if the file
+ # already exists (in the source)
+ if [ -f "${top_srcdir}/${GITREV}" ]
+ then
+ ZFS_GITREV="$(sed -n \
+ '1s/^#define[[:blank:]]ZFS_META_GITREV "\([^"]*\)"$/\1/p' \
+ "${top_srcdir}/${GITREV}")"
+ fi
+elif [ ${dist} = yes ]
+then
+ # Append -dist when creating distributed sources from a git repository
+ ZFS_GITREV="${ZFS_GITREV}-dist"
+fi
ZFS_GITREV=${ZFS_GITREV:-unknown}
GITREVTMP="${GITREV}~"
printf '#define\tZFS_META_GITREV "%s"\n' "${ZFS_GITREV}" >"${GITREVTMP}"
+GITREV="${distdir}/${GITREV}"
if cmp -s "${GITREV}" "${GITREVTMP}"
then
rm -f "${GITREVTMP}"
@@ -27,10 +27,21 @@
top_srcdir="$(dirname "$0")/.."
GITREV="${1:-include/zfs_gitrev.h}"
-# GITREV should be a relative path (relative to top_builddir)
+# GITREV should be a relative path (relative to top_builddir or distdir)
case "${GITREV}" in
/*) echo "Error: ${GITREV} should be a relative path" >&2